<?php

namespace Drupal\unomi;

use Dropsolid\OAuth2\Client\Provider\DropsolidPlatform;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Routing\UrlGeneratorInterface;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use League\OAuth2\Client\Provider\AbstractProvider;
use League\OAuth2\Client\Provider\GenericProvider;
use League\OAuth2\Client\Token\AccessToken;
use Dropsolid\OAuth2\Client\Http\Guzzle\GuzzleApiClientFactory as UnomiClientFactory;
use Dropsolid\UnomiSdkPhp\Unomi;
use Symfony\Component\HttpFoundation\RequestStack;


/**
 * Unomi Integration service.
 */
class UnomiApi implements UnomiApiInterface {

  use StringTranslationTrait;

  /**
   * The Dropsolid Personalization config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $unomiConfig;

  /**
   * Drupal state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The URL generator.
   *
   * @var \Drupal\Core\Routing\UrlGeneratorInterface
   */
  protected $urlGenerator;

  /**
   * The current request object.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a UnomiApi class.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state.
   * @param \Drupal\Core\Routing\UrlGeneratorInterface $url_generator
   *   The URL Generator service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(ConfigFactoryInterface $config_factory, StateInterface $state, UrlGeneratorInterface $url_generator, RequestStack $request_stack, MessengerInterface $messenger) {
    $this->unomiConfig = $config_factory->get('unomi.settings');
    $this->state = $state;
    $this->urlGenerator = $url_generator;
    $this->request = $request_stack->getCurrentRequest();
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public function getClient() {
    // Ask the plugin to give us the Unomiclient
    $unomiConnectorPluginManager = \Drupal::service('plugin.manager.unomi.connector');
    /** @var \Drupal\unomi\UnomiConnectorInterface $connector */
    $connector = $unomiConnectorPluginManager->createInstance($this->unomiConfig->get('connector'), $this->unomiConfig->get('connector_config'));
    return $connector->getClient();
  }

  /**
   * {@inheritdoc}
   * make sure this happens in the plugins. One for basic auth and one for dropsolid platform.
   */
  public function getApiClient() {
    // Ask the plugin to give us the Unomiclient
    $unomiConnectorPluginManager = \Drupal::service('plugin.manager.unomi.connector');
    /** @var \Drupal\unomi\UnomiConnectorInterface $connector */
    $connector = $unomiConnectorPluginManager->createInstance($this->unomiConfig->get('connector'), $this->unomiConfig->get('connector_config'));
    return $connector->getApiClient();
  }



}
